<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:cif="cif">
    <xsl:param name="xslShowHelp" select="cif:xslShowHelp"/>
    <xsl:param name="xslRootDirectory" select="cif:xslRootDirectory"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="cif:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <title lang="en">Incremental Cant Application Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <h2 lang="en">Incremental Cant Application Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="cif:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="cif:time()"/>
                                </p>
                            </center>

                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="@name"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="@description"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="@file"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr />


                                <xsl:for-each select="HorizontalAlignment[*/CantAlignment]">
                                    <table cellpadding="1" width="100%">
                                        <tr>
                                            <th align="right" lang="en" width="20%">
                                                <br/>Horizontal Alignment:&#xa0;
                                            </th>
                                            <td align="left" valign="bottom" width="80%">
                                                <xsl:value-of select="@name"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="white-space:nowrap;">Horizontal Description:&#xa0; </th>
                                            <td align="left">
                                                <xsl:value-of select="@description"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Horizontal Style:&#xa0; </th>
                                            <td align="left">
                                                <xsl:value-of select="@style"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <td colspan="3">
                                                <table width="50%">
                                                    <xsl:if test="//CantPoint">
                                                        <xsl:for-each select="Superelevation/CantAlignment">
                                                            <xsl:if test="//@linearUnits = 'Imperial'">
                                                                <tr>
                                                                    <th class="underline" lang="en" valign="bottom">Station</th>
                                                                    <th class="underline" lang="en" valign="bottom">Left Cant<br/>(in)</th>
                                                                    <th class="underline" lang="en" valign="bottom">Right Cant<br/>(in)</th>
                                                                </tr>
                                                            </xsl:if>
                                                            <xsl:if test="//@linearUnits = 'Metric'">
                                                                <tr>
                                                                    <th class="underline" lang="en" valign="bottom">Station</th>
                                                                    <th class="underline" lang="en" valign="bottom">Left Cant<br/>(mm)</th>
                                                                    <th class="underline" lang="en" valign="bottom">Right Cant<br/>(mm)</th>
                                                                </tr>
                                                            </xsl:if>
                                                            <xsl:for-each select="Cant[position() != last()]">
                                                                <xsl:for-each select="CantPoint">
                                                                    <tr>
                                                                        <xsl:if test="GeometryPoint/@pointType = 'POB' or GeometryPoint/@pointType = 'POT' or GeometryPoint/@pointType = 'POC' or GeometryPoint/@pointType = 'POS' or GeometryPoint/@pointType = 'POE'">
                                                                            <td align="right" style="white-space:nowrap;">
                                                                                <xsl:value-of select="cif:stationFormat(number(GeometryPoint/station/@externalStation), string(GeometryPoint/station/@externalStationName))"/>
                                                                            </td>
                                                                            <td align="right">
                                                                                <xsl:value-of select="cif:formatNumber(number(@leftCant))"/>
                                                                            </td>
                                                                            <td align="right">
                                                                                <xsl:value-of select="cif:formatNumber(number(@rightCant))"/>
                                                                            </td>
                                                                        </xsl:if>
                                                                    </tr>
                                                                </xsl:for-each>
                                                            </xsl:for-each>
                                                        </xsl:for-each>
                                                    </xsl:if>
                                                </table>
                                            </td>
                                        </tr>
                                    </table>
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>

    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field on the
                <em>Tools &gt; XML Reports &gt; Geometry</em> command.
            </p>
            <p class="normal1" lang="en">
                You must also toggle on the <em>Include Cant Alignments</em> option and select either
                <em>All</em> or <em>Active</em> to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2015 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
