<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:cif="cif">
    <xsl:param name="xslShowHelp" select="cif:xslShowHelp"/>
    <xsl:param name="xslRootDirectory" select="cif:xslRootDirectory"/>
    <xsl:param name="xslConvertToCY" select="cif:xslConvertToCY"/>
    <!-- Variable to hold cubic factor -->
    <xsl:variable name="cubicFactor">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">
                <xsl:choose>
                    <xsl:when test="$xslConvertToCY = 1">27</xsl:when>
                    <xsl:otherwise>1</xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>1</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Earthwork Quantities Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="cif:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Výpis objemu zemních prací</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Výpis objemu zemních prací</h2>
                                <p lang="en">
                                    Datum výpisu:&#xa0; <xsl:value-of select="cif:date()"/><br/>
                                    Čas:&#xa0; <xsl:value-of select="cif:time()"/>
                                </p>
                            </center>
                            <!-- Cross Section Set Data -->
                            <xsl:for-each select="CrossSectionSet">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Název sady příčných řezů:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@setName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Název trasy:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@alignmentName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">&#xa0; </th>
                                            <td align="left" style="font-size: 80%"> </td>
                                            <td align="left" lang="en" style="font-size: 80%">
                                                Všechny jednotky tohoto výpisu jsou
                                                <xsl:if test="//@linearUnits = 'Imperial'">
                                                    <xsl:choose>
                                                        <xsl:when test="$xslConvertToCY = 1">
                                                            ve stopách, čtverečních stopách a yardech krychlových,
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            ve stopách, čtverečních stopách a stopách krychlových,
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">
                                                    v metrech, metrech čtverečních a metrech krychlových,
                                                </xsl:if>
                                                pokud není specifikováno jinak.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Volume Data -->
                                <table width="100%">
                                    <colgroup span="14">
                                        <col width="8%"/>
                                        <col width="7%"/>
                                        <col width="7%"/>
                                        <col width="7%"/>
                                        <col width="7%"/>
                                        <col width="7%"/>
                                        <col width="7%"/>
                                        <col width="7%"/>
                                        <col width="7%"/>
                                        <col width="7%"/>
                                        <col width="7%"/>
                                        <col width="7%"/>
                                        <col width="7%"/>
                                        <col width="8%"/>
                                    </colgroup>
                                    <xsl:for-each select="CrossSectionStations">
                                        <thead style="display:table-header-group">
                                            <tr>
                                                <th class="underline" lang="en" rowspan="2" valign="bottom">Základní čára<br/>Staničení</th>
                                                <th class="underline" lang="en" rowspan="2" valign="bottom">Zářez<br/>Zmenšení/<br/>Navýšení<br/>Koeficient</th>
                                                <th class="underline" lang="en" rowspan="2" valign="bottom">Staničení<br/>Zářez<br/>Plocha</th>
                                                <th class="underline" lang="en" rowspan="2" valign="bottom">Staničení<br/>Zářez<br/>Objem</th>
                                                <th class="underline" lang="en" rowspan="2" valign="bottom">Vyrovnaný<br/>Staničení<br/>Zářez</th>
                                                <th class="underline" lang="en" rowspan="2" valign="bottom">Násyp<br/>Zmenšení/<br/>Navýšení<br/>Koeficient</th>
                                                <th class="underline" lang="en" rowspan="2" valign="bottom">Staničení<br/>Násyp<br/>Plocha</th>
                                                <th class="underline" lang="en" rowspan="2" valign="bottom">Staničení<br/>Násyp<br/>Objem</th>
                                                <th class="underline" lang="en" rowspan="2" valign="bottom">Vyrovnaný<br/>Staničení<br/>Násyp</th>
                                                <th colspan="4" lang="en" valign="bottom">- - - - - - - Přidaný objem - - - - - - -</th>
                                                <th class="underline" lang="en" rowspan="2" valign="bottom">Pořadnice<br/>hmoty</th>
                                            </tr>
                                            <tr>
                                                <th class="underline" lang="en" valign="bottom">Zářez</th>
                                                <th class="underline" lang="en" valign="bottom">Vyrovnaný<br>Zářez</th>
                                                <th class="underline" lang="en" valign="bottom">Násyp</th>
                                                <th class="underline" lang="en" valign="bottom">Vyrovnaný<br/>Násyp</th>
                                            </tr>
                                        </thead>
                                        <xsl:for-each select="CrossSectionStation">
                                            <tbody>
                                                <xsl:apply-templates/>
                                            </tbody>
                                            <tfoot style="display:table-footer-group">
                                                <xsl:if test="position() = last()">
                                                    <tr><td colspan="14"><hr/></td></tr>
                                                    <tr>
                                                        <td align="center" colspan="3">Celkem:</td>
                                                        <td align="right">
                                                            <xsl:value-of select="cif:cubicFormat(number((StationVolume/CutMaterial/@cumulativeVolume + sum(StationVolume/*/UnclassifiedMaterials/Material[@includeInMassOrdinate = 'true']/@cumulativeVolume) + sum(StationVolume/*/RockMaterials/Material[@includeInMassOrdinate = 'true']/@cumulativeVolume)) div $cubicFactor))"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="cif:cubicFormat(number((StationVolume/CutMaterial/@cumulativeAdjustedVolume + StationVolume/Materials/MDCMaterials/Material/MDC/@cumulativeAdjustedVolume + sum(StationVolume/*/UnclassifiedMaterials/Material[@includeInMassOrdinate = 'true']/@cumulativeAdjustedVolume) + sum(StationVolume/*/RockMaterials/Material[@includeInMassOrdinate = 'true']/@cumulativeAdjustedVolume)) div $cubicFactor))"/>
                                                        </td>
                                                        <td colspan="2">&#xa0;</td>
                                                        <td align="right">
                                                            <xsl:value-of select="cif:cubicFormat(number((StationVolume/FillMaterial/@cumulativeVolume + sum(StationVolume/*/UnsuitableMaterials/Material[@includeInMassOrdinate = 'true']/Replaced/@cumulativeVolume) + sum(StationVolume/*/DesignedMaterials/Material[@includeInMassOrdinate = 'true']/@cumulativeVolume)) div $cubicFactor))"/>
                                                        </td>
                                                        <xsl:choose>
                                                            <xsl:when test="//MDCMaterials">
                                                                <td align="right">
                                                                    <xsl:value-of select="cif:cubicFormat(number((StationVolume/FillMaterial/@cumulativeAdjustedVolume + StationVolume/Materials/MDCMaterials/Material/@cumulativeAdjustedVolume + sum(StationVolume/*/UnsuitableMaterials/Material[@includeInMassOrdinate = 'true']/Replaced/@cumulativeAdjustedVolume) + sum(StationVolume/*/DesignedMaterials/Material[@includeInMassOrdinate = 'true']/@cumulativeAdjustedVolume)) div $cubicFactor))"/>
                                                                </td>
                                                            </xsl:when>
                                                            <xsl:otherwise>
                                                                <td align="right">
                                                                    <xsl:value-of select="cif:cubicFormat(number((StationVolume/FillMaterial/@cumulativeAdjustedVolume + sum(StationVolume/*/UnsuitableMaterials/Material[@includeInMassOrdinate = 'true']/Replaced/@cumulativeAdjustedVolume) + sum(StationVolume/*/DesignedMaterials/Material[@includeInMassOrdinate = 'true']/@cumulativeAdjustedVolume)) div $cubicFactor))"/>
                                                                </td>
                                                            </xsl:otherwise>
                                                        </xsl:choose>
                                                        <td align="right">
                                                            <xsl:value-of select="cif:cubicFormat(number(StationVolume/AddedCutMaterial/@cumulativeVolume div $cubicFactor))"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="cif:cubicFormat(number(StationVolume/AddedCutMaterial/@cumulativeAdjustedVolume div $cubicFactor))"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="cif:cubicFormat(number(StationVolume/AddedFillMaterial/@cumulativeVolume div $cubicFactor))"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="cif:cubicFormat(number(StationVolume/AddedFillMaterial/@cumulativeAdjustedVolume div $cubicFactor))"/>
                                                        </td>
                                                    </tr>
                                                    <tr><td colspan="14"><hr/></td></tr>
                                                </xsl:if>
                                            </tfoot>
                                        </xsl:for-each>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template match="StationVolume">
        <tr>
            <td align="right" nowrap="nowrap">
                <xsl:value-of select="cif:stationFormat(number(../Station/@externalStation), string(../Station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:distanceFormat(number(CutMaterial/@factor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:areaFormat(number(CutMaterial/@area))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(CutMaterial/@volume div $cubicFactor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(CutMaterial/@adjustedVolume div $cubicFactor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:distanceFormat(number(FillMaterial/@factor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:areaFormat(number(FillMaterial/@area))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(FillMaterial/@volume div $cubicFactor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(FillMaterial/@adjustedVolume div $cubicFactor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(AddedCutMaterial/@volume div $cubicFactor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(AddedCutMaterial/@adjustedVolume div $cubicFactor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(AddedFillMaterial/@volume div $cubicFactor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(AddedFillMaterial/@adjustedVolume div $cubicFactor))"/>
            </td>
        </tr>
        <xsl:if test="//MDCMaterials">
            <tr>
                <td align="right" colspan="4" lang="en">Regulace &#x26; hustoty vlhkosti (neklasifikováno):&#xa0; </td>
                <td colspan="4">&#xa0;</td>
                <td align="right">
                    <xsl:value-of select="cif:cubicFormat(number((Materials/MDCMaterials/Material/@adjustedVolume - Materials/MDCMaterials/Material/MDC/@adjustedVolume) div $cubicFactor))"/>
                </td>
            </tr>
            <tr>
                <td align="right" colspan="4" lang="en">Regulace &#x26; hustoty vlhkosti:&#xa0; </td>
                <td align="right">
                    <xsl:value-of select="cif:cubicFormat(number(Materials/MDCMaterials/Material/MDC/@adjustedVolume div $cubicFactor))"/>
                </td>
                <td colspan="3">&#xa0;</td>
                <td align="right">
                    <xsl:value-of select="cif:cubicFormat(number(Materials/MDCMaterials/Material/MDC/@adjustedVolume div $cubicFactor))"/>
                </td>
            </tr>
        </xsl:if>
        <xsl:for-each select="*/UnsuitableMaterials/Material[@includeInMassOrdinate = 'true']">
            <tr>
                <td align="right" colspan="4"><xsl:value-of select="@name"/>:&#xa0; </td>
                <td align="right"><xsl:value-of select="cif:cubicFormat(number(0.0))"/></td>
                <td colspan="3">&#xa0;</td>
                <td align="right">
                    <xsl:value-of select="cif:cubicFormat(number(Replaced/@adjustedVolume div $cubicFactor))"/>
                </td>
                <td colspan="5">&#xa0;</td>
            </tr>
        </xsl:for-each>
        <xsl:for-each select="*/UnclassifiedMaterials/Material[@includeInMassOrdinate = 'true']">
            <tr>
                <td align="right" colspan="4"><xsl:value-of select="@name"/>:&#xa0; </td>
                <td align="right">
                    <xsl:value-of select="cif:cubicFormat(number(@adjustedVolume div $cubicFactor))"/>
                </td>
                <td colspan="3">&#xa0;</td>
                <td align="right"><xsl:value-of select="cif:cubicFormat(number(0.0))"/></td>
            </tr>
        </xsl:for-each>
        <xsl:for-each select="*/RockMaterials/Material[@includeInMassOrdinate = 'true']">
            <tr>
                <td align="right" colspan="4"><xsl:value-of select="@name"/>:&#xa0; </td>
                <td align="right">
                    <xsl:value-of select="cif:cubicFormat(number(@adjustedVolume div $cubicFactor))"/>
                </td>
                <td colspan="3">&#xa0;</td>
                <td align="right"><xsl:value-of select="cif:cubicFormat(number(0.0))"/></td>
            </tr>
        </xsl:for-each>
        <xsl:for-each select="*/DesignedMaterials/Material[@includeInMassOrdinate = 'true']">
            <tr>
                <td align="right" colspan="4"><xsl:value-of select="@name"/>:&#xa0; </td>
                <td align="right"><xsl:value-of select="cif:cubicFormat(number(0.0))"/></td>
                <td colspan="3">&#xa0;</td>
                <td align="right">
                    <xsl:value-of select="cif:cubicFormat(number(@adjustedVolume div $cubicFactor))"/>
                </td>
            </tr>
        </xsl:for-each>
        <tr>
            <td align="right" colspan="4">Staničení celkem:&#xa0; </td>
            <xsl:choose>
                <xsl:when test="//MDCMaterials">
                    <td class="overline" align="right">
                        <xsl:value-of select="cif:cubicFormat(number((CutMaterial/@adjustedVolume + Materials/MDCMaterials/Material/MDC/@adjustedVolume + sum(*/UnclassifiedMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume) + sum(*/RockMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume)) div $cubicFactor))"/>
                    </td>
                    <td colspan="3">&#xa0;</td>
                    <td class="overline" align="right">
                        <xsl:value-of select="cif:cubicFormat(number((FillMaterial/@adjustedVolume + Materials/MDCMaterials/Material/@adjustedVolume + sum(*/UnsuitableMaterials/Material[@includeInMassOrdinate = 'true']/Replaced/@adjustedVolume) + sum(*/DesignedMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume)) div $cubicFactor))"/>
                    </td>
                </xsl:when>
                <xsl:otherwise>
                    <td class="overline" align="right">
                        <xsl:value-of select="cif:cubicFormat(number((CutMaterial/@adjustedVolume + sum(*/UnclassifiedMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume) + sum(*/RockMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume)) div $cubicFactor))"/>
                    </td>
                    <td colspan="3">&#xa0;</td>
                    <td class="overline" align="right">
                        <xsl:value-of select="cif:cubicFormat(number((FillMaterial/@adjustedVolume + sum(*/UnsuitableMaterials/Material[@includeInMassOrdinate = 'true']/Replaced/@adjustedVolume) + sum(*/DesignedMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume)) div $cubicFactor))"/>
                    </td>
                </xsl:otherwise>
            </xsl:choose>
            <td>&#xa0;</td>
            <td class="overline" align="right">
                <xsl:value-of select="cif:cubicFormat(number(AddedCutMaterial/@adjustedVolume div $cubicFactor))"/>
            </td>
            <td>&#xa0;</td>
            <td class="overline" align="right">
                <xsl:value-of select="cif:cubicFormat(number(AddedFillMaterial/@adjustedVolume div $cubicFactor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(@massOrdinate div $cubicFactor))"/>
            </td>
        </tr>
        <tr><td colspan="14">&#xa0;</td></tr>
    </xsl:template>
    <xsl:template match="DerivedStationVolume">
        <tr>
            <td colspan="14" style="border-style:dashed;border-color:#666633;border-left-width:0px;border-bottom-width:0px;border-top-width:1px;border-right-width:0px">&#xa0;</td>
        </tr>
        <tr>
            <td colspan="4">Bod rovnováhy Staničení:</td>
            <td align="right">
                <xsl:value-of select="cif:stationFormat(number(../Station/@externalStation), string(../Station/@externalStationName))"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="3">Zářez:&#xa0; </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(CutMaterial/@volume div $cubicFactor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(CutMaterial/@adjustedVolume div $cubicFactor))"/>
            </td>
            <td align="right" colspan="2">Násyp:&#xa0; </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(FillMaterial/@volume div $cubicFactor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(FillMaterial/@adjustedVolume div $cubicFactor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(AddedCutMaterial/@volume div $cubicFactor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(AddedCutMaterial/@adjustedVolume div $cubicFactor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(AddedFillMaterial/@volume div $cubicFactor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(AddedFillMaterial/@adjustedVolume div $cubicFactor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(@massOrdinate div $cubicFactor))"/>
            </td>
        </tr>
        <xsl:if test="//MDCMaterials">
            <tr>
                <td align="right" colspan="4" lang="en">Regulace &#x26; hustoty vlhkosti (neklasifikováno):&#xa0; </td>
                <td colspan="4">&#xa0;</td>
                <td align="right">
                    <xsl:value-of select="cif:cubicFormat(number((Materials/MDCMaterials/Material/@adjustedVolume - Materials/MDCMaterials/Material/MDC/@adjustedVolume) div $cubicFactor))"/>
                </td>
            </tr>
            <tr>
                <td align="right" colspan="4" lang="en">Regulace &#x26; hustoty vlhkosti:&#xa0; </td>
                <td align="right">
                    <xsl:value-of select="cif:cubicFormat(number(Materials/MDCMaterials/Material/MDC/@adjustedVolume div $cubicFactor))"/>
                </td>
                <td colspan="3">&#xa0;</td>
                <td align="right">
                    <xsl:value-of select="cif:cubicFormat(number(Materials/MDCMaterials/Material/MDC/@adjustedVolume div $cubicFactor))"/>
                </td>
            </tr>
        </xsl:if>
        <xsl:for-each select="*/UnsuitableMaterials/Material[@includeInMassOrdinate = 'true']">
            <tr>
                <td align="right" colspan="4"><xsl:value-of select="@name"/>:&#xa0; </td>
                <td align="right"><xsl:value-of select="cif:cubicFormat(number(0.0))"/></td>
                <td colspan="3">&#xa0;</td>
                <td align="right">
                    <xsl:value-of select="cif:cubicFormat(number(Replaced/@adjustedVolume div $cubicFactor))"/>
                </td>
            </tr>
        </xsl:for-each>
        <xsl:for-each select="*/UnclassifiedMaterials/Material[@includeInMassOrdinate = 'true']">
            <tr>
                <td align="right" colspan="4"><xsl:value-of select="@name"/>:&#xa0; </td>
                <td align="right">
                    <xsl:value-of select="cif:cubicFormat(number(@adjustedVolume div $cubicFactor))"/>
                </td>
                <td colspan="3">&#xa0;</td>
                <td align="right"><xsl:value-of select="cif:cubicFormat(number(0.0))"/></td>
            </tr>
        </xsl:for-each>
        <xsl:for-each select="*/RockMaterials/Material[@includeInMassOrdinate = 'true']">
            <tr>
                <td align="right" colspan="4"><xsl:value-of select="@name"/>:&#xa0; </td>
                <td align="right">
                    <xsl:value-of select="cif:cubicFormat(number(@adjustedVolume div $cubicFactor))"/>
                </td>
                <td colspan="3">&#xa0;</td>
                <td align="right"><xsl:value-of select="cif:cubicFormat(number(0.0))"/></td>
            </tr>
        </xsl:for-each>
        <xsl:for-each select="*/DesignedMaterials/Material[@includeInMassOrdinate = 'true']">
            <tr>
                <td align="right" colspan="4"><xsl:value-of select="@name"/>:&#xa0; </td>
                <td align="right"><xsl:value-of select="cif:cubicFormat(number(0.0))"/></td>
                <td colspan="3">&#xa0;</td>
                <td align="right">
                    <xsl:value-of select="cif:cubicFormat(number(@adjustedVolume div $cubicFactor))"/>
                </td>
            </tr>
        </xsl:for-each>
        <tr>
            <td align="right" colspan="4">Bod rovnováhy celkový:&#xa0; </td>
            <xsl:choose>
                <xsl:when test="//MDCMaterials">
                    <td class="overline" align="right">
                        <xsl:value-of select="cif:cubicFormat(number((CutMaterial/@adjustedVolume + Materials/MDCMaterials/Material/MDC/@adjustedVolume + sum(*/UnclassifiedMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume) + sum(*/RockMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume)) div $cubicFactor))"/>
                    </td>
                    <td colspan="3">&#xa0;</td>
                    <td class="overline" align="right">
                        <xsl:value-of select="cif:cubicFormat(number((FillMaterial/@adjustedVolume + Materials/MDCMaterials/Material/@adjustedVolume + sum(*/UnsuitableMaterials/Material[@includeInMassOrdinate = 'true']/Replaced/@adjustedVolume) + sum(*/DesignedMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume)) div $cubicFactor))"/>
                    </td>
                </xsl:when>
                <xsl:otherwise>
                    <td class="overline" align="right">
                        <xsl:value-of select="cif:cubicFormat(number((CutMaterial/@adjustedVolume + sum(*/UnclassifiedMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume) + sum(*/RockMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume)) div $cubicFactor))"/>
                    </td>
                    <td colspan="3">&#xa0;</td>
                    <td class="overline" align="right">
                        <xsl:value-of select="cif:cubicFormat(number((FillMaterial/@adjustedVolume + sum(*/UnsuitableMaterials/Material[@includeInMassOrdinate = 'true']/Replaced/@adjustedVolume) + sum(*/DesignedMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume)) div $cubicFactor))"/>
                    </td>
                </xsl:otherwise>
            </xsl:choose>
            <td>&#xa0;</td>
            <td class="overline" align="right">
                <xsl:value-of select="cif:cubicFormat(number(AddedCutMaterial/@adjustedVolume div $cubicFactor))"/>
            </td>
            <td>&#xa0;</td>
            <td class="overline" align="right">
                <xsl:value-of select="cif:cubicFormat(number(AddedFillMaterial/@adjustedVolume div $cubicFactor))"/>
            </td>
            <td align="right">
                <xsl:value-of select="cif:cubicFormat(number(@massOrdinate div $cubicFactor))"/>
            </td>
        </tr>
        <tr>
            <td colspan="14" style="border-style:dashed;border-color:#666633;border-left-width:0px;border-bottom-width:1px;border-top-width:0px;border-right-width:0px">&#xa0;</td>
        </tr>
        <tr><td colspan="14">&#xa0;</td></tr>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Poznámky</h4>
            <p class="normal1" lang="en">
                Musíte vytvořit příčné řezy podél trasy a sada příčných řezů musí
                obsahovat povrchy a prvky, nad kterými chcete provádět výpis.
            </p>
            <p class="normal1" lang="en">
                Soubor dat XML můžete vytvořit příkazem <em>Kubatura z příčných řezů</em> v <em>
                Vyhodnocení &gt; Příčné řezy &gt; Příčné řezy
				</em> se zapnutým parametrem <em>
				  Vytvořit XML výpis
				</em> v záložce <em>Obecně</em> nebo příkazem <em>
				  Vyhodnocení &gt;
				  Příčné řezy &gt; Výpis příčných řezů
				</em> se zapnutým parametrem <em>
				  Včetně objemu
				</em> v záložce <em>Hlavní</em>.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
